@@ -22,10 +22,9 @@ import java.io.IOException;
 import java.math.BigInteger;
 import java.nio.charset.StandardCharsets;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 
 import opennlp.tools.HighMemoryUsage;
 import opennlp.tools.formats.ConllXPOSSampleStream;
@@ -60,7 +59,7 @@ import opennlp.tools.util.model.ModelUtil;
 public class ConllXPosTaggerEval extends AbstractEvalTest {
 
   private POSModel train(File trainFile, String lang,
-                                TrainingParameters params) throws IOException {
+                         TrainingParameters params) throws IOException {
 
     ObjectStream<POSSample> samples =
         new ConllXPOSSampleStream(new MarkableFileInputStreamFactory(trainFile), StandardCharsets.UTF_8);
@@ -69,7 +68,7 @@ public class ConllXPosTaggerEval extends AbstractEvalTest {
   }
 
   private void eval(POSModel model, File testData,
-                           double expectedAccuracy) throws IOException {
+                    double expectedAccuracy) throws IOException {
 
     ObjectStream<POSSample> samples = new ConllXPOSSampleStream(
         new MarkableFileInputStreamFactory(testData), StandardCharsets.UTF_8);
@@ -77,51 +76,55 @@ public class ConllXPosTaggerEval extends AbstractEvalTest {
     POSEvaluator evaluator = new POSEvaluator(new POSTaggerME(model));
     evaluator.evaluate(samples);
 
-    Assert.assertEquals(expectedAccuracy, evaluator.getWordAccuracy(), 0.0001);
+    Assertions.assertEquals(expectedAccuracy, evaluator.getWordAccuracy(), 0.0001);
   }
 
-  @BeforeClass
-  public static void verifyTrainingData() throws Exception {
-    
+  @BeforeAll
+  static void verifyTrainingData() throws Exception {
+
     verifyTrainingData(new ConllXPOSSampleStream(
-        new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
-          "conllx/data/danish/ddt/train/danish_ddt_train.conll")), StandardCharsets.UTF_8), 
+            new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
+                "conllx/data/danish/ddt/train/danish_ddt_train.conll")), StandardCharsets.UTF_8),
         new BigInteger("30795670444498617202001550516753630016"));
-    
-    verifyTrainingData(new ConllXPOSSampleStream(
-        new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
-          "conllx/data/danish/ddt/test/danish_ddt_test.conll")), StandardCharsets.UTF_8), 
-            new BigInteger("314104267846430512372780024568104131337"));
-    
-    verifyTrainingData(new ConllXPOSSampleStream(
-        new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
-          "conllx/data/dutch/alpino/train/dutch_alpino_train.conll")), StandardCharsets.UTF_8), 
-            new BigInteger("109328245573060521952850454797286933887"));
 
     verifyTrainingData(new ConllXPOSSampleStream(
-        new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
-          "conllx/data/dutch/alpino/test/dutch_alpino_test.conll")), StandardCharsets.UTF_8), 
-            new BigInteger("132343141132816640849897155456916243039"));
+            new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
+                "conllx/data/danish/ddt/test/danish_ddt_test.conll")), StandardCharsets.UTF_8),
+        new BigInteger("314104267846430512372780024568104131337"));
 
     verifyTrainingData(new ConllXPOSSampleStream(
-        new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
-          "conllx/data/portuguese/bosque/treebank/portuguese_bosque_train.conll")), StandardCharsets.UTF_8), 
-            new BigInteger("9504382474772307801979515927230835901"));
+            new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
+                "conllx/data/dutch/alpino/train/dutch_alpino_train.conll")), StandardCharsets.UTF_8),
+        new BigInteger("109328245573060521952850454797286933887"));
 
     verifyTrainingData(new ConllXPOSSampleStream(
-        new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
-          "conllx/data/swedish/talbanken05/train/swedish_talbanken05_train.conll")), StandardCharsets.UTF_8), 
-            new BigInteger("175256039869578311901318972681191182910"));
+            new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
+                "conllx/data/dutch/alpino/test/dutch_alpino_test.conll")),
+            StandardCharsets.UTF_8),
+        new BigInteger("132343141132816640849897155456916243039"));
 
     verifyTrainingData(new ConllXPOSSampleStream(
-        new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
-          "conllx/data/swedish/talbanken05/test/swedish_talbanken05_test.conll")), StandardCharsets.UTF_8), 
-            new BigInteger("128378790384268106811747599235147991544"));
-    
+            new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
+                "conllx/data/portuguese/bosque/treebank/portuguese_bosque_train.conll")),
+            StandardCharsets.UTF_8),
+        new BigInteger("9504382474772307801979515927230835901"));
+
+    verifyTrainingData(new ConllXPOSSampleStream(
+            new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
+                "conllx/data/swedish/talbanken05/train/swedish_talbanken05_train.conll")),
+            StandardCharsets.UTF_8),
+        new BigInteger("175256039869578311901318972681191182910"));
+
+    verifyTrainingData(new ConllXPOSSampleStream(
+            new MarkableFileInputStreamFactory(new File(getOpennlpDataDir(),
+                "conllx/data/swedish/talbanken05/test/swedish_talbanken05_test.conll")),
+            StandardCharsets.UTF_8),
+        new BigInteger("128378790384268106811747599235147991544"));
+
   }
 
   @Test
-  public void evalDanishMaxentGis() throws IOException {
+  void evalDanishMaxentGis() throws IOException {
     TrainingParameters params = ModelUtil.createDefaultTrainingParameters();
 
     POSModel maxentModel = train(new File(getOpennlpDataDir(),
@@ -132,7 +135,7 @@ public class ConllXPosTaggerEval extends AbstractEvalTest {
   }
 
   @Test
-  public void evalDanishMaxentQn() throws IOException {
+  void evalDanishMaxentQn() throws IOException {
     TrainingParameters params = createMaxentQnParams();
 
     POSModel maxentModel = train(new File(getOpennlpDataDir(),
@@ -143,7 +146,7 @@ public class ConllXPosTaggerEval extends AbstractEvalTest {
   }
 
   @Test
-  public void evalDutchMaxentGis() throws IOException {
+  void evalDutchMaxentGis() throws IOException {
     TrainingParameters params = ModelUtil.createDefaultTrainingParameters();
 
     POSModel maxentModel = train(new File(getOpennlpDataDir(),
@@ -154,8 +157,8 @@ public class ConllXPosTaggerEval extends AbstractEvalTest {
   }
 
   @Test
-  @Category(HighMemoryUsage.class)
-  public void evalDutchMaxentQn() throws IOException {
+  @HighMemoryUsage
+  void evalDutchMaxentQn() throws IOException {
     TrainingParameters params = createMaxentQnParams();
 
     POSModel maxentModel = train(new File(getOpennlpDataDir(),
@@ -166,7 +169,7 @@ public class ConllXPosTaggerEval extends AbstractEvalTest {
   }
 
   @Test
-  public void evalPortugueseMaxentGis() throws IOException {
+  void evalPortugueseMaxentGis() throws IOException {
     TrainingParameters params = ModelUtil.createDefaultTrainingParameters();
 
     POSModel maxentModel = train(new File(getOpennlpDataDir(),
@@ -177,7 +180,7 @@ public class ConllXPosTaggerEval extends AbstractEvalTest {
   }
 
   @Test
-  public void evalPortugueseMaxentQn() throws IOException {
+  void evalPortugueseMaxentQn() throws IOException {
     TrainingParameters params = createMaxentQnParams();
 
     POSModel maxentModel = train(new File(getOpennlpDataDir(),
@@ -188,7 +191,7 @@ public class ConllXPosTaggerEval extends AbstractEvalTest {
   }
 
   @Test
-  public void evalSwedishMaxentGis() throws IOException {
+  void evalSwedishMaxentGis() throws IOException {
     TrainingParameters params = ModelUtil.createDefaultTrainingParameters();
 
     POSModel maxentModel = train(new File(getOpennlpDataDir(),
@@ -199,7 +202,7 @@ public class ConllXPosTaggerEval extends AbstractEvalTest {
   }
 
   @Test
-  public void evalSwedishMaxentQn() throws IOException {
+  void evalSwedishMaxentQn() throws IOException {
     TrainingParameters params = createMaxentQnParams();
 
     POSModel maxentModel = train(new File(getOpennlpDataDir(),
