@@ -34,10 +34,9 @@ public class LemmaSampleTest {
 
   @Test
   void testParameterValidation() {
-    Assertions.assertThrows(IllegalArgumentException.class, () -> {
-      new LemmaSample(new String[] {""}, new String[] {""},
-          new String[] {"test", "one element to much"});
-    });
+    Assertions.assertThrows(IllegalArgumentException.class,
+            () -> new LemmaSample(new String[] {""}, new String[] {""},
+                    new String[] {"test", "one element to much"}));
   }
 
   private static String[] createSentence() {
@@ -112,10 +111,10 @@ public class LemmaSampleTest {
 
   @Test
   void testEquals() {
-    Assertions.assertFalse(createGoldSample() == createGoldSample());
-    Assertions.assertTrue(createGoldSample().equals(createGoldSample()));
-    Assertions.assertFalse(createPredSample().equals(createGoldSample()));
-    Assertions.assertFalse(createPredSample().equals(new Object()));
+    Assertions.assertNotSame(createGoldSample(), createGoldSample());
+    Assertions.assertEquals(createGoldSample(), createGoldSample());
+    Assertions.assertNotEquals(createPredSample(), createGoldSample());
+    Assertions.assertNotEquals(createPredSample(), new Object());
   }
 
   public static LemmaSample createGoldSample() {
